@@ -41,9 +41,32 @@ enum eRuntimeScript { kRSNoRead, kRSSource, kRSObject };
     // kRSSource ソースファイルを読み込む
     // kRSObject オブジェクトファイルを読み込む
 
+typedef struct 
+{
+    vector_obj* mStatments;
+    string_obj* mSource;
+} sStatments;
+
+sStatments* sStatments_new();
+sStatments* sStatments_new2(sStatments* statments);
+
+typedef struct _sClass {
+    string_obj* name;      // クラス名
+    sStatments* statments; // 命令表
+    struct _sClass* parent;        // オーバーライド先
+    BOOL input;             // 実行時の情報
+} sClass;
+
+sClass* sClass_new(char* name, sStatments* statments, sClass* parent);
+sClass* sClass_new2(sClass* klass);
+  
+void sClass_save(sClass* self, int fd);
+sClass* sClass_load(int fd);
+void sClass_view(sClass* self);
 /// オブジェクトの定義
 typedef struct _sObject {
     string_obj* mName;               /// 自分の名前
+    sClass* mClass;                  /// もしあるなら属しているクラス
     hash_obj* mGlobals;
     hash_obj* mHashs;
     hash_obj* mArrays;
@@ -56,7 +79,7 @@ typedef struct _sObject {
     hash_obj* mMethods;
 } sObject;
 
-sObject* sObject_new(char* name, sObject* parent);
+sObject* sObject_new(char* name, sClass* klass, sObject* parent);
 
 sObject* saphire_get_object(char* name);
     // 引数の名前のオブジェクトを返す
@@ -277,13 +300,6 @@ hash_obj* saphire_get_hash(char* name);
     // ハッシュを返す string_obj*(文字列型)が入ったhash_obj*(ハッシュ)
     // 無ければNULLが返す
 
-typedef struct 
-{
-    vector_obj* mStatments;
-} sStatments;
-
-sStatments* sStatments_new();
-sStatments* sStatments_new2(sStatments* statments);
 BOOL saphire_compile2(char* cmdline, char* fname, sStatments* statments);
     // cmdlineのソースをコンパイルして結果をstatmentsに格納する。
     // コンパイル結果のstatmentsはsaphire_runによって実行できる。
