@@ -241,16 +241,29 @@ enum eCommandKind2 {
     kCKExternCommand
 };
 
+typedef struct
+{
+    int mKind; // 0:string 2: statments 4: statments2 5: block 6: process substituion 7: here document 8:process substituion2 9 : redirect
+    void* mBody;
+} sArg; // mArgs
+
+sArg* sArg_new(int kind, void* body);
+sArg* sArg_new2(sArg* arg);
+void sArg_delete(sArg* arg);
+
+void sArg_save(sArg* self, int fd);
+sArg* sArg_load(int fd);
+
 enum eRedirect { kRedirectInput, kRedirectOverwrite, kRedirectAppend
           , kRedirectErrAndOutput };
 
 typedef struct {
     enum eRedirect mType;
     int mFd;
-    string_obj* mFName;
+    string_obj* mFName;      // ¹Ի˻Ȥ
 } sRedirect; // ¹Ի˻Ȥ ֥ȥե¸
 
-sRedirect* sRedirect_new(enum eRedirect type, int fd, char* fname);
+sRedirect* sRedirect_new(enum eRedirect type, int fd);
 sRedirect* sRedirect_new2(sRedirect* redirect);
 void sRedirect_save(sRedirect* self, int fd);
 sRedirect* sRedirect_load(int fd);
@@ -270,19 +283,6 @@ typedef struct
 
 sPSub* sPSub_new(char* fname, sStatments* statments);
 
-typedef struct
-{
-    int mKind; // 0:string 2: statments 4: statments2 5: block 6: process substituion 7: here document 8:process substituion2
-    void* mBody;
-} sArg; // mArgs
-
-sArg* sArg_new(int kind, void* body);
-sArg* sArg_new2(sArg* arg);
-void sArg_delete(sArg* arg);
-
-void sArg_save(sArg* self, int fd);
-sArg* sArg_load(int fd);
-
 typedef struct
 {
     enum eCommandKind mKind;
