@@ -857,12 +857,12 @@ sJob* sJob_new()
 /////////////////////////////////////////////////////////
 // リダイレクト
 /////////////////////////////////////////////////////////
-sRedirect* sRedirect_new(enum eRedirect type, int fd, char* fname)
+sRedirect* sRedirect_new(enum eRedirect type, int fd)
 {
     sRedirect* self = (sRedirect*)MALLOC(sizeof(sRedirect));
     self->mType = type;
     self->mFd = fd;
-    self->mFName = STRING_NEW(fname);
+    self->mFName = STRING_NEW("");
     return self;
 }
 
@@ -891,24 +891,11 @@ void sRedirect_save(sRedirect* self, int fd)
         perror("write");
         exit(1);
     }
-    
-    n = string_size(self->mFName);
-    if(write(fd, &n, sizeof(int)) < 0) {
-        perror("write");
-        exit(1);
-    }
-    
-    if(write(fd, string_c_str(self->mFName)
-                , string_size(self->mFName)) < 0) 
-    {
-        perror("write");
-        exit(1);
-    }
 }
 
 void sRedirect_view(sRedirect* self)
 {
-    printf("fd %d file %s\n", self->mFd, string_c_str(self->mFName));
+    printf("fd %d\n", self->mFd);
 }
 
 sRedirect* sRedirect_load(int fd)
@@ -929,19 +916,8 @@ sRedirect* sRedirect_load(int fd)
         exit(1);
     }
     self->mFd = n;
-    
-    if(read(fd, &n, sizeof(int)) < 0) {
-        perror("read");
-        exit(1);
-    }
-    
-    char* buf = MALLOC(n+1);
-    if(read(fd, buf, n) < 0) {
-        perror("read");
-        exit(1);
-    }
-    buf[n] = 0;
-    self->mFName = STRING_NEW(buf);
+
+    self->mFName = STRING_NEW("");
     
     return self;
 }
@@ -992,6 +968,9 @@ sArg* sArg_new2(sArg* arg)
     case 8:
         self->mBody = sStatments_new2(arg->mBody);
         break;
+
+    case 9:
+        self->mBody = sRedirect_new2(arg->mBody);
     }
 
     return self;
@@ -1057,6 +1036,10 @@ void sArg_save(sArg* self, int fd)
         case 8:
             sStatments_save(self->mBody, fd);
             break;
+
+        case 9:
+            sRedirect_save(self->mBody, fd);
+            break;
     }
 }
 
@@ -1126,6 +1109,8 @@ sArg* sArg_load(int fd)
         self->mBody = sStatments_load(fd);
         break;
 
+    case 9:
+        self->mBody = sRedirect_load(fd);
     }
 
     return self;
@@ -1414,10 +1399,6 @@ sCommand* sCommand_new2(sCommand* command)
         self->mExtra = sWhile_new2(command->mExtra);
         break;
         
-    case kTry:
-        self->mExtra = sTry_new2(command->mExtra);
-        break;
-
     case kSubshell:
         self->mExtra = sSubshell_new2(command->mExtra);
         break;
@@ -1456,10 +1437,6 @@ void sCommand_view(sCommand* self)
         sWhile_view(self->mExtra);
         break;
         
-    case kTry:
-        sTry_view(self->mExtra);
-        break;
-
     case kSubshell:
         sSubshell_view(self->mExtra);
         break;
@@ -1512,10 +1489,6 @@ void sCommand_save(sCommand* self, int fd)
         sWhile_save(self->mExtra, fd);
         break;
 
-    case kTry:
-        sTry_save(self->mExtra, fd);
-        break;
-        
     case kSubshell:
         sSubshell_save(self->mExtra, fd);
         break;
@@ -1569,10 +1542,6 @@ sCommand* sCommand_load(int fd)
         self->mExtra = sWhile_load(fd);
         break;
 
-    case kTry:
-        self->mExtra = sTry_load(fd);
-        break;
-        
     case kSubshell:
         self->mExtra = sSubshell_load(fd);
         break;
@@ -2625,7 +2594,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "3.3.4", 1);
+    setenv("SAPHIRE_VERSION", "3.3.5", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
