@@ -755,76 +755,6 @@ static BOOL read_command_parse_if_statment(char** p, sCommand* command, sStatmen
     return TRUE;
 }
 
-/// try文読み込み
-static BOOL read_command_parse_try_statment(char** p, sCommand* command, sStatment* statment, string_obj* not_evaled, int* read_end_of_statment, char* sname, int* sline)
-{
-    skip_spaces(p, not_evaled);
-
-    /// 文読み込み ///
-    sStatments* loops = STATMENTS_NEW();
-
-    if(**p == '{') {
-        string_obj* str = STRING_NEW("");
-        if(!read_block(p, str, NULL, not_evaled, FALSE, sname, sline)) {
-            return FALSE;
-        }
-
-        if(!parse(string_c_str(str), sname, sline, loops))
-        {
-            return FALSE;
-        }
-    }
-    else {
-        err_msg("expected block.", sname, *sline);
-        return FALSE;
-    }
-
-    skip_spaces(p, not_evaled);
-
-    sStatments* loops2 = STATMENTS_NEW();
-    if(strstr(*p, "catch") == *p) {
-        string_push_back2(not_evaled, **p);
-        (*p)++;
-        string_push_back2(not_evaled, **p);
-        (*p)++;
-        string_push_back2(not_evaled, **p);
-        (*p)++;
-        string_push_back2(not_evaled, **p);
-        (*p)++;
-        string_push_back2(not_evaled, **p);
-        (*p)++;
-
-        skip_spaces(p, not_evaled);
-
-        if(**p == '{') {
-            string_obj* str = STRING_NEW("");
-            if(!read_block(p, str, NULL, not_evaled, FALSE, sname, sline)) {
-                return FALSE;
-            }
-
-            if(!parse(string_c_str(str), sname, sline, loops2))
-            {
-                return FALSE;
-            }
-        }
-        else {
-            err_msg("expected block.", sname, *sline);
-            return FALSE;
-        }
-    }
-    else {
-        err_msg("expected catch word", sname, *sline);
-
-    }
-
-    command->mKind = kTry;
-        // これが無いとmNotEvaledの場合（変数がある場合）
-        // 正しくcommandが消されない
-    command->mExtra = sTry_new(loops, loops2);
-
-    return TRUE;
-}
-
 /// while文読み込み
 static BOOL read_command_parse_while_statment(char** p, sCommand* command, sStatment* statment, string_obj* not_evaled, int* read_end_of_statment, char* sname, int* sline)
 {
@@ -895,7 +825,7 @@ static BOOL read_command_parse_while_statment(char** p, sCommand* command, sStat
 }
 
 /// １コマンド読み込み
-static BOOL read_command(char** p, sCommand* command, sStatment* statment, string_obj* not_evaled, int* read_end_of_statment, BOOL block_termination, char* sname, int* sline)
+static BOOL read_command(char** p, sCommand* command, sStatment* statment, string_obj* not_evaled, int* read_end_of_statment, char* sname, int* sline)
 {
     while(**p) {
         string_obj* buf = STRING_NEW("");
@@ -927,16 +857,6 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
                         return FALSE;
                     }
                 }
-                else if(strcmp(string_c_str(buf), "try") == 0) {
-                    vector_add(command->mArgs, sArg_new(0, buf));
-                    string_push_back(statment->mTitle, string_c_str(buf));
-                    string_push_back(statment->mTitle, " ");
-
-                    if(!read_command_parse_try_statment(p, command, statment, not_evaled, read_end_of_statment, sname, sline))
-                    {
-                        return FALSE;
-                    }
-                }
                 else {
                     if(vector_size(statment->mCommands) == 0 && strcmp(string_c_str(buf), "!") == 0)
                     {
@@ -1046,21 +966,7 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
 
                 skip_spaces(p, not_evaled);
 
-                string_obj* fname = STRING_NEW("");
-                if(!read_one_argument(p, fname, not_evaled, read_end_of_statment, NULL, sname, sline))
-                {
-                    return FALSE;
-                }
-
-                // クィックコマンド展開は置けない
-                if(string_c_str(fname)[0] == 0 && (**p == '@' && *(*p+1) == '(' || **p == '@' && *(*p+1) == '@' && *(*p+2) == '(')) {
-                    err_msg("can't put a @ command expression after redirect", sname, *sline);
-                    return FALSE;
-                }
-
-                vector_add(command->mRedirects
-                        , sRedirect_new(type, fd, string_c_str(fname)));
-
+                vector_add(command->mArgs, sArg_new(9, sRedirect_new(type, fd)));
             }
             /// リダイレクト
             else {
@@ -1071,21 +977,7 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
 
                 skip_spaces(p, not_evaled);
 
-                string_obj* fname = STRING_NEW("");
-                if(!read_one_argument(p, fname, not_evaled, read_end_of_statment, NULL, sname, sline))
-                {
-                    return FALSE;
-                }
-
-                // クィックコマンド展開は置けない
-                if(string_c_str(fname)[0] == 0 && (**p == '@' && *(*p+1) == '(' || **p == '@' && *(*p+1) == '@' && *(*p+2) == '(')) {
-                    err_msg("can't put a @ command expression after redirect", sname, *sline);
-                    return FALSE;
-                }
-
-                vector_add(command->mRedirects
-                        , sRedirect_new(type, fd, string_c_str(fname)));
-
+                vector_add(command->mArgs, sArg_new(9, sRedirect_new(type, fd)));
             }
         }
         else if(**p == '<') {
@@ -1253,22 +1145,8 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
                 enum eRedirect type = kRedirectInput;
 
                 skip_spaces(p, not_evaled);
-
-                string_obj* fname = STRING_NEW("");
-                if(!read_one_argument(p, fname, not_evaled, read_end_of_statment, NULL, sname, sline))
-                {
-                    return FALSE;
-                }
-
-                // クィックコマンド展開は置けない
-                if(string_c_str(fname)[0] == 0 && (**p == '@' && *(*p+1) == '(' || **p == '@' && *(*p+1) == '@' && *(*p+2) == '(')) {
-                    err_msg("can't put a @ command expression after redirect", sname, *sline);
-                    return FALSE;
-                }
-
-                vector_add(command->mRedirects
-                        , sRedirect_new(type, fd, string_c_str(fname)));
-
+                
+                vector_add(command->mArgs, sArg_new(9, sRedirect_new(type, fd)));
             }
         }
         /// リダイレクト ///
@@ -1286,20 +1164,7 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
 
                 skip_spaces(p, not_evaled);
 
-                string_obj* fname = STRING_NEW("");
-                if(!read_one_argument(p, fname, not_evaled, read_end_of_statment, NULL, sname, sline))
-                {
-                    return FALSE;
-                }
-
-                // クィックコマンド展開は置けない
-                if(string_c_str(fname)[0] == 0 && (**p == '@' && *(*p+1) == '(' || **p == '@' && *(*p+1) == '@' && *(*p+2) == '(')) {
-                    err_msg("can't put a @ command expression after redirect", sname, *sline);
-                    return FALSE;
-                }
-
-                vector_add(command->mRedirects
-                        , sRedirect_new(type, fd, string_c_str(fname)));
+                vector_add(command->mArgs, sArg_new(9, sRedirect_new(type, fd)));
 
             }
             else if(*(*p+1) == '2' && *(*p+2) == '>') {
@@ -1310,20 +1175,7 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
 
                 skip_spaces(p, not_evaled);
 
-                string_obj* fname = STRING_NEW("");
-                if(!read_one_argument(p, fname, not_evaled, read_end_of_statment, NULL, sname, sline))
-                {
-                    return FALSE;
-                }
-
-                // クィックコマンド展開は置けない
-                if(string_c_str(fname)[0] == 0 && (**p == '@' && *(*p+1) == '(' || **p == '@' && *(*p+1) == '@' && *(*p+2) == '(')) {
-                    err_msg("can't put a @ command expression after redirect", sname, *sline);
-                    return FALSE;
-                }
-
-                vector_add(command->mRedirects
-                        , sRedirect_new(type, fd, string_c_str(fname)));
+                vector_add(command->mArgs, sArg_new(9, sRedirect_new(type, fd)));
 
             }
             else if(*(*p+1) == '>') {
@@ -1335,20 +1187,7 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
 
                 skip_spaces(p, not_evaled);
 
-                string_obj* fname = STRING_NEW("");
-                if(!read_one_argument(p, fname, not_evaled, read_end_of_statment, NULL, sname, sline))
-                {
-                    return FALSE;
-                }
-
-                // クィックコマンド展開は置けない
-                if(string_c_str(fname)[0] == 0 && (**p == '@' && *(*p+1) == '(' || **p == '@' && *(*p+1) == '@' && *(*p+2) == '(')) {
-                    err_msg("can't put a @ command expression after redirect", sname, *sline);
-                    return FALSE;
-                }
-
-                vector_add(command->mRedirects
-                        , sRedirect_new(type, fd, string_c_str(fname)));
+                vector_add(command->mArgs, sArg_new(9, sRedirect_new(type, fd)));
 
             }
             else {
@@ -1432,7 +1271,7 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, strin
 }
 
 /// 一文読み込み
-static BOOL read_statment(char**p, sStatment* statment, string_obj* not_evaled, int* read_end_of_statment, BOOL block_termination, char* sname, int* sline)
+static BOOL read_statment(char**p, sStatment* statment, string_obj* not_evaled, int* read_end_of_statment, char* sname, int* sline)
 {
     /// 反転 ///
     if(**p == '!') {
@@ -1479,7 +1318,7 @@ static BOOL read_statment(char**p, sStatment* statment, string_obj* not_evaled,
 
     while(**p) {
         sCommand* command = COMMAND_NEW();
-        if(!read_command(p, command, statment, not_evaled, read_end_of_statment, block_termination, sname, sline)) 
+        if(!read_command(p, command, statment, not_evaled, read_end_of_statment, sname, sline)) 
         {
             return FALSE;
         }
@@ -1533,7 +1372,7 @@ BOOL parse(char* cmdline, char* sname, int* sline, sStatments* statments)
             // コマンドライン展開があったので行末まで読み込む
         int line_of_head = *sline;
 
-        if(!read_statment(&p, statment, not_evaled, &read_end_of_statment, FALSE, sname, sline))
+        if(!read_statment(&p, statment, not_evaled, &read_end_of_statment, sname, sline))
         {
             return FALSE;
         }
