@@ -44,7 +44,7 @@ static BOOL statment_tree_redirect(sCommand* command, sRFd ** nextin, sWFd** nex
                     mode = O_WRONLY | O_CREAT | O_APPEND;
                     break;
             }
-            
+
             int openfd = open(string_c_str(redirect->mFName), mode, 0666);
             if(openfd < 0) {
                 char buf[PATH_MAX];
@@ -114,7 +114,6 @@ static BOOL statment_tree_redirect(sCommand* command, sRFd ** nextin, sWFd** nex
 // forkした子供(外部コマンド)をexecさせたい関数
 static BOOL statment_tree_exec_cprog(sCommand* command, int nextin, int nextout, int nexterr, vector_obj* argv, char* sname, int sline)
 {
-//puts("statment_tree_exec_cprog");
     /// リダイレクト ///
     int err_and_output = FALSE;
     int k;
@@ -230,7 +229,7 @@ static BOOL statment_tree_exec_cprog(sCommand* command, int nextin, int nextout,
 }
 
 // 外部コマンドの処理
-static BOOL statment_tree_external_command(sStatment* statment, vector_obj* argv, sRFd* nextin, sWFd* nextout, int nexterr, sWFd* pipeout, sCommand* command, BOOL last_program, int* last_program_pid, char* sname, int sline, vector_obj* envs)
+static BOOL statment_tree_external_command(sStatment* statment, vector_obj* argv, sRFd* nextin, sWFd* nextout, int nexterr, sWFd* pipeout, sCommand* command, BOOL last_program, int* last_program_pid, char* sname, int sline, vector_obj* envs, vector_obj* blocks, vector_obj* parent_blocks, BOOL* return_, BOOL enable_return, BOOL* break_, BOOL enable_break, sRFd* pipein, vector_obj* psubs, sObject* object, sFunction* running_fun, sClass* running_class)
 {
 //printf("nextin %d nextout %d\n", nextin->mFd, nextout->mFd);
     char* argv0 = string_c_str(vector_item(argv, 0));
@@ -505,13 +504,21 @@ static BOOL statment_tree_external_command(sStatment* statment, vector_obj* argv
 /// argvを作る
 static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, BOOL* return_, BOOL enable_return, BOOL* break_, BOOL enable_break, sRFd* nextin, sRFd* pipein, char* sname, int sline, vector_obj* envs, vector_obj* psubs, sObject* object, sFunction* running_fun, sClass* running_class)
 {
+    sRedirect* redirect = NULL;
+
     int ii;
     for(ii=0; ii<vector_size(command->mArgs); ii++) {
         sArg* arg = vector_item(command->mArgs, ii);
         switch(arg->mKind) {
             /// string ///
             case 0:
-                vector_add(argv, STRING_NEW(string_c_str(arg->mBody)));
+                if(redirect) {
+                    string_put(redirect->mFName, string_c_str(arg->mBody));
+                    redirect = NULL;
+                }
+                else {
+                    vector_add(argv, STRING_NEW(string_c_str(arg->mBody)));
+                }
                 break;
 
             /// @ のコマンド展開　///
@@ -526,7 +533,13 @@ static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_
                     return FALSE;
                 }
 
-                vector_add(argv, STRING_NEW(pipeout->mBuffer));
+                if(redirect) {
+                    string_put(redirect->mFName, pipeout->mBuffer);
+                    redirect = NULL;
+                }
+                else {
+                    vector_add(argv, STRING_NEW(pipeout->mBuffer));
+                }
                 }
                 break;
 
@@ -555,7 +568,13 @@ static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_
                     }
 
                     string_chomp(str);
-                    vector_add(argv, str);
+                    if(redirect) {
+                        string_put(redirect->mFName, string_c_str(str));
+                        redirect = NULL;
+                    }
+                    else {
+                        vector_add(argv, str);
+                    }
                 }
 
                 }
@@ -606,7 +625,13 @@ static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_
 
                 (void)close(fd);
 
-                vector_add(argv, STRING_NEW(fname));
+                if(redirect) {
+                    string_put(redirect->mFName, fname);
+                    redirect = NULL;
+                }
+                else {
+                    vector_add(argv, STRING_NEW(fname));
+                }
                 }
                 break;
 
@@ -640,7 +665,13 @@ static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_
                 }
                 (void)close(f);
 
-                vector_add(argv, STRING_NEW(fname));
+                if(redirect) {
+                    string_put(redirect->mFName, fname);
+                    redirect = NULL;
+                }
+                else {
+                    vector_add(argv, STRING_NEW(fname));
+                }
                 }
                 break;
 
@@ -665,14 +696,40 @@ static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_
                     if(flg == 0) break;
                 }
                 vector_add(gTmpFiles, STRING_NEW(fname));
-                vector_add(argv, STRING_NEW(fname));
                 vector_add(psubs, sPSub_new(fname, statments));
+
+                if(redirect) {
+                    string_put(redirect->mFName, fname);
+                    redirect = NULL;
+                }
+                else {
+                    vector_add(argv, STRING_NEW(fname));
+                }
                 }
                 break;
 
+            /// リダイレクト ///
+            case 9: {
+                sRedirect* redirect2 = arg->mBody;
+
+                vector_add(command->mRedirects, redirect2);
+
+                if(redirect2->mType == kRedirectErrAndOutput) {
+                    redirect = NULL;
+                }
+                else {
+                    redirect = arg->mBody;
+                }
+                }
+                break;
         }
     }
 
+    if(redirect) {
+        err_msg("redirect file name doesn't exist" , sname, sline);
+        return FALSE;
+    }
+
     return TRUE;
 }
 
@@ -1039,11 +1096,13 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
         else if(method) {
             method->input = input;
 
-            if(!statment_tree_redirect(command, &nextin, &nextout
-                            , &nexterr, pipein, pipeout, pipeerr, sname, sline))
+            if(!statment_tree_redirect(command, &nextin, &nextout, &nexterr, pipein, pipeout, pipeerr, sname, sline))
             {
                 return FALSE;
             }
+            if(*return_) {
+                return TRUE;
+            }
 
             /// 引数名が指定されていなければスタックフレームを増やす ///
             vector_obj* fun_argv_before;
@@ -1159,11 +1218,13 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
         else if(fun) {
             fun->input = input;
 
-            if(!statment_tree_redirect(command, &nextin, &nextout
-                            , &nexterr, pipein, pipeout, pipeerr, sname, sline))
+            if(!statment_tree_redirect(command, &nextin, &nextout, &nexterr, pipein, pipeout, pipeerr, sname, sline))
             {
                 return FALSE;
             }
+            if(*return_) {
+                return TRUE;
+            }
 
             /// 引数名が指定されていなければスタックフレームを増やす ///
             vector_obj* fun_argv_before;
@@ -1276,12 +1337,13 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
         /// 外部登録の内部コマンド ///
         else if(inner_fun) {
-            if(!statment_tree_redirect(command, &nextin, &nextout
-                                    , &nexterr
-                                    , pipein, pipeout, pipeerr, sname, sline))
+            if(!statment_tree_redirect(command, &nextin, &nextout, &nexterr, pipein, pipeout, pipeerr, sname, sline))
             {
                 return FALSE;
             }
+            if(*return_) {
+                return TRUE;
+            }
 
             *rcode = 1; // 初期値は1。コマンドが成功したら0を入れる
 
@@ -1317,12 +1379,13 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
         /// 内部コマンド ///
         else if(command->mKind != kCommand) {
 //printf("command->mKind %d %s\n", command->mKind, gStatmentKindStrs[command->mKind]);
-            if(!statment_tree_redirect(command, &nextin, &nextout
-                                    , &nexterr
-                                    , pipein, pipeout, pipeerr, sname, sline))
+            if(!statment_tree_redirect(command, &nextin, &nextout, &nexterr, pipein, pipeout, pipeerr, sname, sline))
             {
                 return FALSE;
             }
+            if(*return_) {
+                return TRUE;
+            }
 
             *rcode = 1; // 初期値は1。コマンドが成功したら0を入れる
 
@@ -1375,17 +1438,21 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
                 nextin->mFd = -1;
 
-                if(!statment_tree_external_command(statment, argv, nextin, nextout, nexterr, pipeout, command, last_program, last_program_pid, sname, sline, envs))
+                if(!statment_tree_external_command(statment, argv, nextin, nextout, nexterr, pipeout, command, last_program, last_program_pid, sname, sline, envs, blocks, parent_blocks, return_, enable_return, break_, enable_break, pipein, psubs, object, running_fun, running_class))
                 {
                     return FALSE;
                 }
             }
             else {
-                if(!statment_tree_external_command(statment, argv, nextin, nextout, nexterr, pipeout, command, last_program, last_program_pid,  sname, sline, envs))
+                if(!statment_tree_external_command(statment, argv, nextin, nextout, nexterr, pipeout, command, last_program, last_program_pid, sname, sline, envs, blocks, parent_blocks, return_, enable_return, break_, enable_break, pipein, psubs, object, running_fun, running_class))
                 {
                     return FALSE;
                 }
             }
+
+            if(*return_) {
+                return TRUE;
+            }
         }
 
         /// パイプを閉める ///
